var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
import { toRef, computed, createVNode, mergeProps, withDirectives, vShow } from "vue";
import "./styles/badge.scss";
import { convertToUnit, pick } from "../../utils/dist/index.mjs";
import { defineComponent } from "../../utils/define-component.mjs";
import { Icon } from "../icon/icon.mjs";
import "../icon/icon-class.mjs";
import "../icon/icon-component.mjs";
import "../icon/icon-ligature.mjs";
import "../icon/icon-svg.mjs";
import { FadeTransition } from "../transition/fade-transition.mjs";
import "../transition/scale-transition.mjs";
import "../transition/expand-transition.mjs";
import "../transition/dialog-transition.mjs";
import "../transition/menu-transition.mjs";
import "../transition/fade-in-expand-transition.mjs";
import "../transition/slide-right-fade-in-expand-transition.mjs";
import { makeShapeProps, useShape } from "../../composables/shape/index.mjs";
import { makeTagProps } from "../../composables/tag/index.mjs";
import { makeTransitionProps, MaybeTransition } from "../../composables/transition/index.mjs";
import { useBackgroundColor, useTextColor } from "../../composables/color/index.mjs";
const Badge = defineComponent({
  name: "VeBadge",
  inheritAttrs: false,
  props: __spreadValues(__spreadValues(__spreadValues({
    bordered: {
      type: Boolean,
      default: true
    },
    color: String,
    content: [Number, String],
    dot: Boolean,
    floating: Boolean,
    icon: [String, Object],
    inline: Boolean,
    location: {
      type: String,
      default: "top-right",
      validator: (value) => {
        const [vertical, horizontal] = (value != null ? value : "").split("-");
        return ["top", "bottom"].includes(vertical) && ["left", "right"].includes(horizontal);
      }
    },
    max: [Number, String],
    modelValue: {
      type: Boolean,
      default: true
    },
    offsetX: [Number, String],
    offsetY: [Number, String],
    textColor: String
  }, makeShapeProps()), makeTagProps()), makeTransitionProps({
    transition: {
      component: FadeTransition
    }
  })),
  setup(props, {
    slots,
    attrs
  }) {
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, "color"));
    const {
      shapeClasses
    } = useShape(props);
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(toRef(props, "textColor"));
    const position = computed(() => props.floating ? props.dot ? 2 : 4 : props.dot ? 8 : 12);
    function calculatePosition(offset) {
      return `calc(100% - ${convertToUnit(position.value + Number(offset != null ? offset : 0))})`;
    }
    const locationStyles = computed(() => {
      var _a;
      const [vertical, horizontal] = ((_a = props.location) != null ? _a : "").split("-");
      const styles = {
        bottom: "auto",
        left: "auto",
        right: "auto",
        top: "auto"
      };
      if (!props.inline) {
        styles[horizontal === "left" ? "right" : "left"] = calculatePosition(props.offsetX);
        styles[vertical === "top" ? "bottom" : "top"] = calculatePosition(props.offsetY);
      }
      return styles;
    });
    return () => {
      const value = Number(props.content);
      const content = !props.max || isNaN(value) ? props.content : value <= props.max ? value : `${props.max}+`;
      const [badgeAttrs, restAttrs] = pick(attrs, ["aria-atomic", "aria-label", "aria-live", "role", "title"]);
      return createVNode(props.tag, mergeProps({
        "class": ["ve-badge", {
          "ve-badge--bordered": props.bordered,
          "ve-badge--dot": props.dot,
          "ve-badge--floating": props.floating,
          "ve-badge--inline": props.inline
        }]
      }, restAttrs), {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots), createVNode(MaybeTransition, {
            "transition": props.transition
          }, {
            default: () => {
              var _a2, _b;
              return [withDirectives(createVNode("span", mergeProps({
                "class": ["ve-badge__content", backgroundColorClasses.value, shapeClasses.value, textColorClasses.value],
                "style": [backgroundColorStyles.value, locationStyles.value, textColorStyles.value],
                "aria-atomic": "true",
                "aria-label": "locale string here",
                "aria-live": "polite",
                "role": "status"
              }, badgeAttrs), [!props.dot && (((_b = (_a2 = slots.badge) == null ? void 0 : _a2.call(slots)) != null ? _b : props.icon) ? createVNode(Icon, {
                "icon": props.icon
              }, null) : content)]), [[vShow, props.modelValue]])];
            }
          })];
        }
      });
    };
  }
});
export { Badge };
//# sourceMappingURL=badge.mjs.map
