import type { ValidationRule } from '../../composables/validation';
import type { Size } from '../../composables/size';
import type { ComponentInternalInstance, ExtractPropTypes, VNodeChild, VNode, RendererNode, RendererElement, VNodeProps, AllowedComponentProps, ComponentCustomProps, Slot, ComponentPublicInstance, ComponentOptionsBase, ComponentOptionsMixin, DebuggerEvent, nextTick, WatchOptions, WatchStopHandle, ShallowUnwrapRef, ComponentCustomProperties, ComputedRef,  PropType,  Ref } from 'vue';
import type { MakeSlots } from '../../utils';
export declare type FormControlSlot = {
    isDisabled: ComputedRef<boolean>;
    isReadonly: ComputedRef<boolean>;
    isPristine: Ref<boolean | null>;
    isValid: ComputedRef<boolean | null>;
    isValidating: Ref<boolean>;
    reset: () => void;
    resetValidation: () => void;
    validate: () => void;
};
export declare type FormControlSlots = MakeSlots<{
    prepend: [FormControlSlot];
    label: [FormControlSlot];
    default: [FormControlSlot & {
        props: Record<string, unknown>;
    }];
    append: [FormControlSlot];
    details: [FormControlSlot];
}>;
export declare function filterFormControlSlots(slots: Record<string, unknown>): [yes: Partial<Pick<Record<string, unknown>, string>>, no: Omit<Record<string, unknown>, string>];
export declare const FormControlEmits: {
    'click:prepend': (_event: MouseEvent) => boolean;
    'click:label': (_event: MouseEvent) => boolean;
    'click:append': (_event: MouseEvent) => boolean;
    'update:modelValue': (_modelValue: any) => boolean;
};
export declare const FormControlSlots: string[];
export declare const FormControl: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            readonly: boolean;
            direction: "vertical" | "horizontal";
            errorMessages: string | string[];
            focused: boolean;
            persistentHint: boolean;
            messages: string | unknown[];
            maxErrors: string | number;
            rules: ValidationRule[];
        }> & Omit<Readonly<ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 布局方向
             */
            direction: {
                type: PropType<"vertical" | "horizontal">;
                default: string;
                validator: (v: any) => boolean;
            };
            /**
             * @zh 聚焦的
             */
            focused: BooleanConstructor;
            /**
             * @zh 隐藏详情
             */
            hideDetails: PropType<boolean | "auto">;
            /**
             * @zh 存在提示
             */
            hint: StringConstructor;
            /**
             * @zh 内联
             */
            inline: BooleanConstructor;
            /**
             * @zh 标签文本
             */
            label: (BooleanConstructor | StringConstructor)[];
            /**
             * @zh 标签ID
             */
            labelId: StringConstructor;
            /**
             * @zh 标签宽度
             */
            labelWidth: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 提示消息
             */
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            /**
             * @zh 名称
             */
            name: StringConstructor;
            /**
             * @zh 后置图标
             */
            prependIcon: StringConstructor;
            /**
             * @zh 持续显示的提示
             */
            persistentHint: BooleanConstructor;
        } & {
            $children: () => VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        } & VNodeProps & AllowedComponentProps & ComponentCustomProps, "error" | "disabled" | "size" | "density" | "inline" | "readonly" | "direction" | "errorMessages" | "focused" | "persistentHint" | "messages" | "maxErrors" | "rules">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:prepend", _event: MouseEvent) => void) & ((event: "click:label", _event: MouseEvent) => void) & ((event: "click:append", _event: MouseEvent) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 布局方向
             */
            direction: {
                type: PropType<"vertical" | "horizontal">;
                default: string;
                validator: (v: any) => boolean;
            };
            /**
             * @zh 聚焦的
             */
            focused: BooleanConstructor;
            /**
             * @zh 隐藏详情
             */
            hideDetails: PropType<boolean | "auto">;
            /**
             * @zh 存在提示
             */
            hint: StringConstructor;
            /**
             * @zh 内联
             */
            inline: BooleanConstructor;
            /**
             * @zh 标签文本
             */
            label: (BooleanConstructor | StringConstructor)[];
            /**
             * @zh 标签ID
             */
            labelId: StringConstructor;
            /**
             * @zh 标签宽度
             */
            labelWidth: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 提示消息
             */
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            /**
             * @zh 名称
             */
            name: StringConstructor;
            /**
             * @zh 后置图标
             */
            prependIcon: StringConstructor;
            /**
             * @zh 持续显示的提示
             */
            persistentHint: BooleanConstructor;
        } & {
            $children: () => VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        }, {
            isDisabled: ComputedRef<boolean>;
            isReadonly: ComputedRef<boolean>;
            isPristine: Ref<boolean>;
            isValid: ComputedRef<boolean | null>;
            isValidating: Ref<boolean>;
            reset: () => void;
            resetValidation: () => void;
            validate: () => Promise<string[]>;
        }, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {
            'click:prepend': (_event: MouseEvent) => boolean;
            'click:label': (_event: MouseEvent) => boolean;
            'click:append': (_event: MouseEvent) => boolean;
            'update:modelValue': (_modelValue: any) => boolean;
        }, string, {
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            readonly: boolean;
            direction: "vertical" | "horizontal";
            errorMessages: string | string[];
            focused: boolean;
            persistentHint: boolean;
            messages: string | unknown[];
            maxErrors: string | number;
            rules: ValidationRule[];
        }> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: DebuggerEvent) => void) | ((e: DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: DebuggerEvent) => void) | ((e: DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null, info: string) => boolean | void) | ((err: unknown, instance: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<ExtractPropTypes<{
        disabled: BooleanConstructor;
        error: BooleanConstructor;
        errorMessages: {
            type: PropType<string | string[]>;
            default: () => never[];
        };
        maxErrors: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
        };
        readonly: BooleanConstructor;
        rules: {
            type: PropType<ValidationRule[]>;
            default: () => never[];
        };
        modelValue: null;
        density: {
            type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: {
            type: PropType<Size | undefined>;
            default: string;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        /**
         * @zh 后置图标
         */
        appendIcon: (StringConstructor | ObjectConstructor)[];
        /**
         * @zh 布局方向
         */
        direction: {
            type: PropType<"vertical" | "horizontal">;
            default: string;
            validator: (v: any) => boolean;
        };
        /**
         * @zh 聚焦的
         */
        focused: BooleanConstructor;
        /**
         * @zh 隐藏详情
         */
        hideDetails: PropType<boolean | "auto">;
        /**
         * @zh 存在提示
         */
        hint: StringConstructor;
        /**
         * @zh 内联
         */
        inline: BooleanConstructor;
        /**
         * @zh 标签文本
         */
        label: (BooleanConstructor | StringConstructor)[];
        /**
         * @zh 标签ID
         */
        labelId: StringConstructor;
        /**
         * @zh 标签宽度
         */
        labelWidth: (StringConstructor | NumberConstructor)[];
        /**
         * @zh 提示消息
         */
        messages: {
            type: (StringConstructor | ArrayConstructor)[];
            default: () => never[];
        };
        /**
         * @zh 名称
         */
        name: StringConstructor;
        /**
         * @zh 后置图标
         */
        prependIcon: StringConstructor;
        /**
         * @zh 持续显示的提示
         */
        persistentHint: BooleanConstructor;
    } & {
        $children: () => VNodeChild | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | {
            prepend?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            label?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            default?: VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            append?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            details?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
    } & ShallowUnwrapRef<{
        isDisabled: ComputedRef<boolean>;
        isReadonly: ComputedRef<boolean>;
        isPristine: Ref<boolean>;
        isValid: ComputedRef<boolean | null>;
        isValidating: Ref<boolean>;
        reset: () => void;
        resetValidation: () => void;
        validate: () => Promise<string[]>;
    }> & {} & {} & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<ExtractPropTypes<{
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    errorMessages: {
        type: PropType<string | string[]>;
        default: () => never[];
    };
    maxErrors: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    readonly: BooleanConstructor;
    rules: {
        type: PropType<ValidationRule[]>;
        default: () => never[];
    };
    modelValue: null;
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 后置图标
     */
    appendIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 布局方向
     */
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
        validator: (v: any) => boolean;
    };
    /**
     * @zh 聚焦的
     */
    focused: BooleanConstructor;
    /**
     * @zh 隐藏详情
     */
    hideDetails: PropType<boolean | "auto">;
    /**
     * @zh 存在提示
     */
    hint: StringConstructor;
    /**
     * @zh 内联
     */
    inline: BooleanConstructor;
    /**
     * @zh 标签文本
     */
    label: (BooleanConstructor | StringConstructor)[];
    /**
     * @zh 标签ID
     */
    labelId: StringConstructor;
    /**
     * @zh 标签宽度
     */
    labelWidth: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 提示消息
     */
    messages: {
        type: (StringConstructor | ArrayConstructor)[];
        default: () => never[];
    };
    /**
     * @zh 名称
     */
    name: StringConstructor;
    /**
     * @zh 后置图标
     */
    prependIcon: StringConstructor;
    /**
     * @zh 持续显示的提示
     */
    persistentHint: BooleanConstructor;
} & {
    $children: () => VNodeChild | ((args_0: FormControlSlot & {
        props: Record<string, unknown>;
    }) => VNode<RendererNode, RendererElement, {
        [key: string]: any;
    }> | VNode<RendererNode, RendererElement, {
        [key: string]: any;
    }>[]) | {
        prepend?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        label?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        default?: VNodeChild | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        append?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        details?: VNodeChild | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        label?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        append?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        details?: false | ((args_0: FormControlSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
    "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
}, {
    isDisabled: ComputedRef<boolean>;
    isReadonly: ComputedRef<boolean>;
    isPristine: Ref<boolean>;
    isValid: ComputedRef<boolean | null>;
    isValidating: Ref<boolean>;
    reset: () => void;
    resetValidation: () => void;
    validate: () => Promise<string[]>;
}, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {
    'click:prepend': (_event: MouseEvent) => boolean;
    'click:label': (_event: MouseEvent) => boolean;
    'click:append': (_event: MouseEvent) => boolean;
    'update:modelValue': (_modelValue: any) => boolean;
}, string, {
    error: boolean;
    disabled: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    readonly: boolean;
    direction: "vertical" | "horizontal";
    errorMessages: string | string[];
    focused: boolean;
    persistentHint: boolean;
    messages: string | unknown[];
    maxErrors: string | number;
    rules: ValidationRule[];
}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & (new () => {
    $slots: FormControlSlots;
});
export declare type FormControl = InstanceType<typeof FormControl>;
//# sourceMappingURL=form-control.d.ts.map