var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { capitalize, computed, createVNode, isVNode } from "vue";
import "./styles/row.scss";
import { propsFactory, convertToUnit } from "../../utils/dist/index.mjs";
import { defineComponent } from "../../utils/define-component.mjs";
import { makeTagProps } from "../../composables/tag/index.mjs";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const breakpoints = ["sm", "md", "lg", "xl", "xxl"];
const alignments = ["start", "end", "center"];
function makeProps(prefix, def) {
  return breakpoints.reduce((props, val) => {
    props[prefix + capitalize(val)] = def();
    return props;
  }, {});
}
const alignValidator = (str) => [...alignments, "baseline", "stretch"].includes(str);
const alignProps = makeProps("align", () => ({
  type: String,
  default: null,
  validator: alignValidator
}));
const justifyValidator = (str) => [...alignments, "space-between", "space-around"].includes(str);
const justifyProps = makeProps("justify", () => ({
  type: String,
  default: null,
  validator: justifyValidator
}));
const alignContentValidator = (str) => [...alignments, "space-between", "space-around", "stretch"].includes(str);
const alignContentProps = makeProps("alignContent", () => ({
  type: String,
  default: null,
  validator: alignContentValidator
}));
const propMap = {
  align: Object.keys(alignProps),
  justify: Object.keys(justifyProps),
  alignContent: Object.keys(alignContentProps)
};
const classMap = {
  align: "align",
  justify: "justify",
  alignContent: "align-content"
};
function breakpointClass(type, prop, val) {
  let className = classMap[type];
  if (val == null) {
    return void 0;
  }
  if (prop) {
    const breakpoint = prop.replace(type, "");
    className += `-${breakpoint}`;
  }
  className += `-${val}`;
  return className.toLowerCase();
}
const GUTTERS = ["xs", "sm", "md", "lg", "xl", "xxl", "x-small", "small", "medium", "large", "x-large", "xx-large"];
const GUTTERS_ALIASES = {
  "x-small": "xs",
  "small": "sm",
  "medium": "md",
  "large": "lg",
  "x-large": "xl",
  "xx-large": "xxl"
};
const makeRowProps = propsFactory(__spreadValues(__spreadProps(__spreadValues(__spreadProps(__spreadValues({
  gutter: {
    type: [Number, String],
    default: "xl"
  },
  align: {
    type: String,
    default: null,
    validator: alignValidator
  }
}, alignProps), {
  justify: {
    type: String,
    default: null,
    validator: justifyValidator
  }
}), justifyProps), {
  alignContent: {
    type: String,
    default: null,
    validator: alignContentValidator
  }
}), alignContentProps), "row");
const Row = defineComponent({
  name: "VeRow",
  props: __spreadValues(__spreadValues({}, makeTagProps()), makeRowProps()),
  setup(props, {
    slots
  }) {
    const classes = computed(() => {
      const classList = [];
      let type;
      for (type in propMap) {
        propMap[type].forEach((prop) => {
          const value = props[prop];
          const className = breakpointClass(type, prop, value);
          if (className)
            classList.push(className);
        });
      }
      if (GUTTERS.includes(props.gutter)) {
        let gutter = props.gutter;
        if (props.gutter in GUTTERS_ALIASES) {
          gutter = GUTTERS_ALIASES[gutter];
        }
        classList.push(`ve-row--gutter-${gutter}`);
      }
      classList.push({
        [`align-${props.align}`]: props.align,
        [`justify-${props.justify}`]: props.justify,
        [`align-content-${props.alignContent}`]: props.alignContent
      });
      return classList;
    });
    const styles = computed(() => {
      if (GUTTERS.includes(props.gutter))
        return {};
      return {
        "--ve-row-gutter": convertToUnit(props.gutter)
      };
    });
    return () => createVNode(props.tag, {
      "class": ["ve-row", classes.value],
      "style": styles.value
    }, _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }
});
export { Row, makeRowProps };
//# sourceMappingURL=row.mjs.map
