var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
import { defineComponent, ref, computed, watch, onBeforeMount, nextTick, h, createVNode, withDirectives, vShow, isVNode, resolveDirective } from "vue";
import "./styles/image.scss";
import { SUPPORTS_INTERSECTION_OBSERVER, IN_BROWSER, useRender, convertToUnit } from "../../utils/dist/index.mjs";
import { Responsive } from "../responsive/responsive.mjs";
import { makeTransitionProps, MaybeTransition } from "../../composables/transition/index.mjs";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Image = defineComponent({
  name: "VeImage",
  props: __spreadValues({
    aspectRatio: [String, Number],
    alt: String,
    cover: Boolean,
    eager: Boolean,
    gradient: String,
    lazySrc: String,
    options: {
      type: Object,
      default: () => ({
        root: void 0,
        rootMargin: void 0,
        threshold: void 0
      })
    },
    sizes: String,
    src: String,
    srcset: String,
    width: [String, Number]
  }, makeTransitionProps()),
  emits: {
    loadstart: (_src, _image) => true,
    load: (_src, _image) => true,
    error: (_src, _image) => true
  },
  setup(props, {
    emit,
    slots
  }) {
    const currentSrc = ref("");
    const image = ref();
    const state = ref(props.eager ? "loading" : "idle");
    const naturalWidth = ref();
    const naturalHeight = ref();
    const aspectRatio = computed(() => {
      return Number(props.aspectRatio || 0) || naturalWidth.value / naturalHeight.value || 0;
    });
    watch(() => props.src, () => {
      init(state.value !== "idle");
    });
    onBeforeMount(() => init());
    function init(isIntersecting) {
      if (props.eager && isIntersecting)
        return;
      if (SUPPORTS_INTERSECTION_OBSERVER && !isIntersecting && !props.eager)
        return;
      state.value = "loading";
      if (props.lazySrc && IN_BROWSER) {
        const lazyImg = new window.Image();
        lazyImg.src = props.lazySrc;
        pollForSize(lazyImg, null);
      }
      if (!props.src)
        return;
      nextTick(() => {
        var _a, _b;
        emit("loadstart", ((_a = image.value) == null ? void 0 : _a.currentSrc) || props.src, image.value);
        if ((_b = image.value) == null ? void 0 : _b.complete) {
          if (!image.value.naturalWidth)
            onError();
          if (state.value === "error")
            return;
          if (!aspectRatio.value)
            pollForSize(image.value, null);
          onLoad();
        } else {
          if (!aspectRatio.value)
            pollForSize(image.value);
          getSrc();
        }
      });
    }
    function onLoad() {
      var _a;
      getSrc();
      state.value = "loaded";
      emit("load", ((_a = image.value) == null ? void 0 : _a.currentSrc) || props.src, image.value);
    }
    function onError() {
      var _a;
      state.value = "error";
      emit("error", ((_a = image.value) == null ? void 0 : _a.currentSrc) || props.src, image.value);
    }
    function getSrc() {
      const img = image.value;
      if (img)
        currentSrc.value = img.currentSrc || img.src;
    }
    function pollForSize(img, timeout = 100) {
      const poll = () => {
        const {
          naturalHeight: imgHeight,
          naturalWidth: imgWidth
        } = img;
        if (imgHeight || imgWidth) {
          naturalWidth.value = imgWidth;
          naturalHeight.value = imgHeight;
        } else if (!img.complete && state.value === "loading" && timeout != null) {
          setTimeout(poll, timeout);
        } else if (img.currentSrc.endsWith(".svg") || img.currentSrc.startsWith("data:image/svg+xml")) {
          naturalWidth.value = 1;
          naturalHeight.value = 1;
        }
      };
      poll();
    }
    const containClasses = computed(() => ({
      "ve-image__img--cover": props.cover,
      "ve-image__img--contain": !props.cover
    }));
    const __image = computed(() => {
      var _a;
      let _slot;
      if (!props.src || state.value === "idle")
        return;
      const img = h("img", {
        class: ["ve-image__img", containClasses.value],
        src: props.src,
        srcset: props.srcset,
        sizes: props.sizes,
        ref: image,
        onLoad,
        onError
      });
      const sources = (_a = slots.sources) == null ? void 0 : _a.call(slots);
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, _isSlot(_slot = withDirectives(sources ? createVNode("picture", {
        "class": "ve-image__picture"
      }, [sources, img]) : img, [[vShow, state.value === "loaded"]])) ? _slot : {
        default: () => [_slot]
      });
    });
    const __preloadImage = computed(() => createVNode(MaybeTransition, {
      "transition": props.transition
    }, {
      default: () => [props.lazySrc && state.value !== "loaded" && createVNode("img", {
        "class": ["ve-image__img", "ve-image__img--preload", containClasses.value],
        "src": props.lazySrc,
        "alt": ""
      }, null)]
    }));
    const __placeholder = computed(() => {
      if (!slots.placeholder)
        return;
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, {
        default: () => [(state.value === "loading" || state.value === "error" && !slots.error) && createVNode("div", {
          "class": "ve-image__placeholder"
        }, [slots.placeholder()])]
      });
    });
    const __error = computed(() => {
      if (!slots.error)
        return;
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, {
        default: () => [state.value === "error" && createVNode("div", {
          "class": "ve-image__error"
        }, [slots.error()])]
      });
    });
    const __gradient = computed(() => {
      if (!props.gradient)
        return;
      return createVNode("div", {
        "class": "ve-image__gradient",
        "style": {
          backgroundImage: `linear-gradient(${props.gradient})`
        }
      }, null);
    });
    const isBooted = ref(false);
    {
      const stop = watch(aspectRatio, (val) => {
        if (val) {
          requestAnimationFrame(() => {
            requestAnimationFrame(() => {
              isBooted.value = true;
            });
          });
          stop();
        }
      });
    }
    useRender(() => withDirectives(createVNode(Responsive, {
      "class": ["ve-image", {
        "ve-image--booting": !isBooted.value
      }],
      "style": {
        width: convertToUnit(props.width === "auto" ? naturalWidth.value : props.width)
      },
      "aspectRatio": aspectRatio.value,
      "aria-label": props.alt,
      "role": props.alt ? "img" : void 0
    }, {
      additional: () => [__image.value, __preloadImage.value, __gradient.value, __placeholder.value, __error.value],
      default: slots.default
    }), [[resolveDirective("intersect"), {
      handler: init,
      options: props.options
    }, null, {
      once: true
    }]]));
    return {
      currentSrc,
      image,
      state,
      naturalWidth,
      naturalHeight
    };
  }
});
export { Image };
//# sourceMappingURL=image.mjs.map
