import type { RouteLocationRaw } from 'vue-router';
import type { Size } from '../../composables/size';
import type { ComponentInternalInstance, ExtractPropTypes, PropType, VNodeChild, VNode, RendererNode, RendererElement, VNodeProps, AllowedComponentProps, ComponentCustomProps, Slot, ComponentPublicInstance, ComponentOptionsBase, ComponentOptionsMixin, DebuggerEvent, nextTick, WatchOptions, WatchStopHandle, ShallowUnwrapRef, ComponentCustomProperties } from 'vue';
import type { MakeSlots } from '../../utils';
declare type ListItemSlot = {
    isActive: boolean;
    activate: (value: boolean) => void;
    isSelected: boolean;
    select: (value: boolean) => void;
};
export declare type ListItemTitleSlot = {
    title?: string;
};
export declare type ListItemSubtitleSlot = {
    subtitle?: string;
};
export declare const ListItem: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            replace: boolean;
            fixed: boolean;
            link: boolean;
            ripple: boolean;
            disabled: boolean;
            tag: string;
            variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
            absolute: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
            active: boolean;
            activeColor: string;
        }> & Omit<Readonly<ExtractPropTypes<{
            href: StringConstructor;
            replace: BooleanConstructor;
            to: PropType<RouteLocationRaw>;
            disabled: BooleanConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: {
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: Omit<{
                type: PropType<Size | undefined>;
                default: string;
            }, "default" | "type"> & {
                type: PropType<Size | undefined>;
                default: Size | undefined;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 是否激活
             */
            active: BooleanConstructor;
            /**
             * @zh 激活时的颜色
             */
            activeColor: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 激活时的 class
             */
            activeClass: StringConstructor;
            /**
             * @zh 后置头像
             */
            appendAvatar: StringConstructor;
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 是否是一个链接
             */
            link: BooleanConstructor;
            /**
             * @zh 前置头像
             */
            prependAvatar: StringConstructor;
            /**
             * @zh 前置图标
             */
            prependIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 点击时是否有波纹
             */
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 副标题
             */
            subtitle: StringConstructor;
            /**
             * @zh 文本内容
             */
            text: StringConstructor;
            /**
             * @zh 标题
             */
            title: StringConstructor;
            /**
             * @zh 列表项的值
             */
            value: null;
        } & {
            $children: () => VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: VNodeChild | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: VNodeChild | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "replace" | "fixed" | "link" | "ripple" | "disabled" | "tag" | "variant" | "absolute" | "size" | "density" | "shape" | "active" | "activeColor">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: ComponentOptionsBase<Readonly<ExtractPropTypes<{
            href: StringConstructor;
            replace: BooleanConstructor;
            to: PropType<RouteLocationRaw>;
            disabled: BooleanConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: {
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: Omit<{
                type: PropType<Size | undefined>;
                default: string;
            }, "default" | "type"> & {
                type: PropType<Size | undefined>;
                default: Size | undefined;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 是否激活
             */
            active: BooleanConstructor;
            /**
             * @zh 激活时的颜色
             */
            activeColor: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 激活时的 class
             */
            activeClass: StringConstructor;
            /**
             * @zh 后置头像
             */
            appendAvatar: StringConstructor;
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 是否是一个链接
             */
            link: BooleanConstructor;
            /**
             * @zh 前置头像
             */
            prependAvatar: StringConstructor;
            /**
             * @zh 前置图标
             */
            prependIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 点击时是否有波纹
             */
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 副标题
             */
            subtitle: StringConstructor;
            /**
             * @zh 文本内容
             */
            text: StringConstructor;
            /**
             * @zh 标题
             */
            title: StringConstructor;
            /**
             * @zh 列表项的值
             */
            value: null;
        } & {
            $children: () => VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: VNodeChild | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: VNodeChild | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }> | VNode<RendererNode, RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, () => JSX.Element, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, {
            replace: boolean;
            fixed: boolean;
            link: boolean;
            ripple: boolean;
            disabled: boolean;
            tag: string;
            variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
            absolute: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
            active: boolean;
            activeColor: string;
        }> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: DebuggerEvent) => void) | ((e: DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: DebuggerEvent) => void) | ((e: DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null, info: string) => boolean | void) | ((err: unknown, instance: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<ExtractPropTypes<{
        href: StringConstructor;
        replace: BooleanConstructor;
        to: PropType<RouteLocationRaw>;
        disabled: BooleanConstructor;
        elevation: {
            type: (StringConstructor | NumberConstructor)[];
            validator(v: any): boolean;
        };
        shape: {
            type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        };
        border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        density: {
            type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: Omit<{
            type: PropType<Size | undefined>;
            default: string;
        }, "default" | "type"> & {
            type: PropType<Size | undefined>;
            default: Size | undefined;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        absolute: BooleanConstructor;
        bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        fixed: BooleanConstructor;
        left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        position: {
            type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
            validator: (v: any) => boolean;
        };
        right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
        };
        theme: StringConstructor;
        tag: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 是否激活
         */
        active: BooleanConstructor;
        /**
         * @zh 激活时的颜色
         */
        activeColor: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 激活时的 class
         */
        activeClass: StringConstructor;
        /**
         * @zh 后置头像
         */
        appendAvatar: StringConstructor;
        /**
         * @zh 后置图标
         */
        appendIcon: (StringConstructor | ObjectConstructor)[];
        /**
         * @zh 是否是一个链接
         */
        link: BooleanConstructor;
        /**
         * @zh 前置头像
         */
        prependAvatar: StringConstructor;
        /**
         * @zh 前置图标
         */
        prependIcon: (StringConstructor | ObjectConstructor)[];
        /**
         * @zh 点击时是否有波纹
         */
        ripple: {
            type: BooleanConstructor;
            default: boolean;
        };
        /**
         * @zh 副标题
         */
        subtitle: StringConstructor;
        /**
         * @zh 文本内容
         */
        text: StringConstructor;
        /**
         * @zh 标题
         */
        title: StringConstructor;
        /**
         * @zh 列表项的值
         */
        value: null;
    } & {
        $children: () => VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | {
            prepend?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            append?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            default?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            title?: VNodeChild | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
            subtitle?: VNodeChild | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            title?: false | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            subtitle?: false | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }> | VNode<RendererNode, RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & ShallowUnwrapRef<() => JSX.Element> & {} & {} & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<ExtractPropTypes<{
    href: StringConstructor;
    replace: BooleanConstructor;
    to: PropType<RouteLocationRaw>;
    disabled: BooleanConstructor;
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: Omit<{
        type: PropType<Size | undefined>;
        default: string;
    }, "default" | "type"> & {
        type: PropType<Size | undefined>;
        default: Size | undefined;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 是否激活
     */
    active: BooleanConstructor;
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 激活时的 class
     */
    activeClass: StringConstructor;
    /**
     * @zh 后置头像
     */
    appendAvatar: StringConstructor;
    /**
     * @zh 后置图标
     */
    appendIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 是否是一个链接
     */
    link: BooleanConstructor;
    /**
     * @zh 前置头像
     */
    prependAvatar: StringConstructor;
    /**
     * @zh 前置图标
     */
    prependIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 点击时是否有波纹
     */
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 副标题
     */
    subtitle: StringConstructor;
    /**
     * @zh 文本内容
     */
    text: StringConstructor;
    /**
     * @zh 标题
     */
    title: StringConstructor;
    /**
     * @zh 列表项的值
     */
    value: null;
} & {
    $children: () => VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
        [key: string]: any;
    }> | VNode<RendererNode, RendererElement, {
        [key: string]: any;
    }>[]) | {
        prepend?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        append?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        default?: VNodeChild | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        title?: VNodeChild | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
        subtitle?: VNodeChild | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        append?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: ListItemSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        title?: false | ((args_0: ListItemTitleSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        subtitle?: false | ((args_0: ListItemSubtitleSlot) => VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }> | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, () => JSX.Element, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, {
    replace: boolean;
    fixed: boolean;
    link: boolean;
    ripple: boolean;
    disabled: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    active: boolean;
    activeColor: string;
}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & (new () => {
    $slots: MakeSlots<{
        prepend: [ListItemSlot];
        append: [ListItemSlot];
        default: [ListItemSlot];
        title: [ListItemTitleSlot];
        subtitle: [ListItemSubtitleSlot];
    }>;
});
export declare type ListItem = InstanceType<typeof ListItem>;
export {};
//# sourceMappingURL=list-item.d.ts.map