var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { ref, computed, createVNode, createTextVNode, nextTick } from "vue";
import "./styles/pagination.scss";
import { createRange, keyValues } from "../../utils/dist/index.mjs";
import { defineComponent } from "../../utils/define-component.mjs";
import { Button } from "../button/button.mjs";
import { Select } from "../select/select.mjs";
import { Input } from "../input/input.mjs";
import { makePaperProps, usePaper } from "../../composables/paper/index.mjs";
import { useResizeObserver } from "../../composables/resize-observer/index.mjs";
import { useRefs } from "../../composables/refs/index.mjs";
import { useProxiedModel } from "../../composables/proxied-model/index.mjs";
const Pagination = defineComponent({
  name: "VePagination",
  props: __spreadValues({
    activeColor: {
      type: String,
      default: "primary"
    },
    ariaLabel: {
      type: String,
      default: "\u5206\u9875\u5BFC\u822A"
    },
    currentPageAriaLabel: {
      type: String,
      default: "\u5F53\u524D\u9875 {0}"
    },
    disabled: Boolean,
    ellipsis: {
      type: String,
      default: "..."
    },
    firstAriaLabel: {
      type: String,
      default: "\u9996\u9875"
    },
    firstPage: {
      type: [Number, String],
      default: 1
    },
    firstIcon: {
      type: String,
      default: "$first"
    },
    lastAriaLabel: {
      type: String,
      default: "\u6700\u540E\u9875"
    },
    lastIcon: {
      type: String,
      default: "$last"
    },
    modelValue: {
      type: [Number, String],
      default: (props) => props.firstPage,
      validator: (val) => val % 1 === 0
    },
    nextAriaLabel: {
      type: String,
      default: "\u4E0B\u4E00\u9875"
    },
    nextIcon: {
      type: String,
      default: "$next"
    },
    prevIcon: {
      type: String,
      default: "$prev"
    },
    pageAriaLabel: {
      type: String,
      default: "\u8F6C\u5230\u9875\u9762 {0}"
    },
    perPage: {
      type: [Number, String],
      default: 10,
      validator: (val) => val % 1 === 0
    },
    perPageOptions: {
      type: Array,
      default: () => [10, 20, 50, 100]
    },
    previousAriaLabel: {
      type: String,
      default: "\u4E0A\u4E00\u9875"
    },
    showFirstLastPage: Boolean,
    showQuickJumper: Boolean,
    showPerPageSelect: Boolean,
    total: {
      type: [Number, String],
      default: 0,
      validator: (val) => val % 1 === 0
    },
    totalVisible: {
      type: [Number, String],
      validator: (val) => val % 1 === 0
    }
  }, makePaperProps({
    tag: "nav",
    variant: "text",
    shape: "rounded-sm"
  })),
  emits: {
    "update:modelValue": (_modelValue) => true,
    "update:perPage": (_perPage) => true,
    "first": (_value) => true,
    "prev": (_value) => true,
    "next": (_value) => true,
    "last": (_value) => true
  },
  setup(props, {
    slots,
    emit
  }) {
    const internalPage = ref();
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const page = useProxiedModel(props, "modelValue", props.modelValue, (v) => parseInt(v != null ? v : 1, 10));
    const perPage = useProxiedModel(props, "perPage", props.perPage, (v) => parseInt(v != null ? v : 10, 10));
    const total = computed(() => parseInt(props.total, 10));
    const firstPage = computed(() => parseInt(props.firstPage, 10));
    const lastPage = computed(() => Math.ceil(total.value / perPage.value));
    const maxButtons = ref(-1);
    const {
      resizeRef
    } = useResizeObserver((entries) => {
      if (!entries.length)
        return;
      const {
        target,
        contentRect
      } = entries[0];
      const firstItem = target.querySelector(".ve-pagination__wrapper > *");
      if (!firstItem)
        return;
      let totalWidth = contentRect.width - 96;
      if (props.showPerPageSelect)
        totalWidth -= 100;
      if (props.showQuickJumper)
        totalWidth -= 100;
      const itemWidth = firstItem.getBoundingClientRect().width + 10;
      maxButtons.value = Math.max(0, Math.floor(totalWidth / itemWidth));
    });
    const totalVisible = computed(() => {
      if (props.totalVisible)
        return Math.min(parseInt(props.totalVisible, 10), lastPage.value);
      if (maxButtons.value >= 0)
        return maxButtons.value;
      return Math.min(7, lastPage.value);
    });
    const range = computed(() => {
      if (lastPage.value <= 0)
        return [];
      if (totalVisible.value === 1)
        return [Math.min(Math.max(firstPage.value, page.value), firstPage.value + lastPage.value)];
      if (lastPage.value <= totalVisible.value)
        return createRange(lastPage.value, firstPage.value);
      const middle = Math.ceil(totalVisible.value / 2);
      const left = middle;
      const right = lastPage.value - middle;
      if (page.value < left) {
        return [...createRange(Math.max(1, totalVisible.value - 2), firstPage.value), props.ellipsis, lastPage.value];
      }
      if (page.value > right) {
        const rangeLength2 = totalVisible.value - 2;
        const rangeStart2 = lastPage.value - rangeLength2 + firstPage.value;
        return [firstPage.value, props.ellipsis, ...createRange(rangeLength2, rangeStart2)];
      }
      const rangeLength = Math.max(1, totalVisible.value - 4);
      const rangeStart = rangeLength === 1 ? page.value : page.value - Math.ceil(rangeLength / 2) + firstPage.value;
      return [firstPage.value, props.ellipsis, ...createRange(rangeLength, rangeStart), props.ellipsis, lastPage.value];
    });
    function setValue(e, value, event) {
      e.preventDefault();
      page.value = value;
      event && emit(event, value);
    }
    const {
      refs,
      updateRef
    } = useRefs();
    const items = computed(() => {
      const sharedProps = {
        density: props.density,
        shape: props.shape,
        size: props.size
      };
      return range.value.map((item, index) => {
        const ref2 = (e) => updateRef(e, index);
        if (typeof item === "string") {
          return {
            isActive: false,
            page: item,
            props: __spreadProps(__spreadValues({}, sharedProps), {
              ref: ref2,
              ellipsis: true,
              icon: true,
              disabled: true,
              variant: props.variant,
              border: props.border
            })
          };
        } else {
          const isActive = item === page.value;
          return {
            isActive,
            page: item,
            props: __spreadProps(__spreadValues({}, sharedProps), {
              ref: ref2,
              ellipsis: false,
              icon: true,
              disabled: props.disabled || lastPage.value < 2,
              elevation: props.elevation,
              variant: isActive ? "outlined" : props.variant,
              border: props.border,
              color: isActive ? props.activeColor : void 0,
              ariaCurrent: isActive,
              ariaLabel: isActive ? props.currentPageAriaLabel : props.pageAriaLabel,
              onClick: (e) => setValue(e, item)
            })
          };
        }
      });
    });
    const controls = computed(() => {
      const sharedProps = {
        color: void 0,
        density: props.density,
        shape: props.shape,
        size: props.size,
        variant: "outlined",
        border: props.border
      };
      const prevDisabled = props.disabled || page.value <= firstPage.value;
      const nextDisabled = props.disabled || page.value >= firstPage.value + lastPage.value - 1;
      return {
        first: props.showFirstLastPage ? __spreadProps(__spreadValues({}, sharedProps), {
          icon: props.firstIcon,
          onClick: (e) => setValue(e, firstPage.value, "first"),
          disabled: prevDisabled,
          ariaLabel: props.firstAriaLabel,
          ariaDisabled: prevDisabled
        }) : void 0,
        prev: __spreadProps(__spreadValues({}, sharedProps), {
          icon: props.prevIcon,
          onClick: (e) => setValue(e, page.value - 1, "prev"),
          disabled: prevDisabled,
          ariaLabel: props.previousAriaLabel,
          ariaDisabled: prevDisabled
        }),
        next: __spreadProps(__spreadValues({}, sharedProps), {
          icon: props.nextIcon,
          onClick: (e) => setValue(e, page.value + 1, "next"),
          disabled: nextDisabled,
          ariaLabel: props.nextAriaLabel,
          ariaDisabled: nextDisabled
        }),
        last: props.showFirstLastPage ? __spreadProps(__spreadValues({}, sharedProps), {
          icon: props.lastIcon,
          onClick: (e) => setValue(e, firstPage.value + lastPage.value - 1, "last"),
          disabled: nextDisabled,
          ariaLabel: props.lastAriaLabel,
          ariaDisabled: nextDisabled
        }) : void 0
      };
    });
    function updateFocus() {
      var _a;
      const currentIndex = page.value - firstPage.value;
      (_a = refs.value[currentIndex]) == null ? void 0 : _a.$el.focus();
    }
    function onKeydown({
      key
    }) {
      if (key === keyValues.left && !props.disabled && page.value > firstPage.value) {
        page.value = page.value - 1;
        nextTick(updateFocus);
      } else if (key === keyValues.right && !props.disabled && page.value < firstPage.value + lastPage.value - 1) {
        page.value = page.value + 1;
        nextTick(updateFocus);
      }
    }
    return () => createVNode(props.tag, {
      "ref": resizeRef,
      "class": ["ve-pagination", paperClasses.value],
      "style": paperStyles.value,
      "role": "navigation",
      "aria-label": props.ariaLabel,
      "onKeydown": onKeydown
    }, {
      default: () => {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        return [createVNode("ul", {
          "class": "ve-pagination__wrapper"
        }, [props.showFirstLastPage && createVNode("li", {
          "class": "ve-pagination__first"
        }, [(_b = (_a = slots.first) == null ? void 0 : _a.call(slots, controls.value.first)) != null ? _b : createVNode(Button, controls.value.first, null)]), createVNode("li", {
          "class": "ve-pagination__prev"
        }, [(_d = (_c = slots.prev) == null ? void 0 : _c.call(slots, controls.value.prev)) != null ? _d : createVNode(Button, controls.value.prev, null)]), items.value.map((item, index) => {
          var _a2, _b2;
          return createVNode("li", {
            "key": `${index}_${item.page}`,
            "class": ["ve-pagination__item", {
              "ve-pagination__item--is-active": item.isActive
            }]
          }, [(_b2 = (_a2 = slots.item) == null ? void 0 : _a2.call(slots, item)) != null ? _b2 : createVNode(Button, item.props, {
            default: () => [item.page]
          })]);
        }), createVNode("li", {
          "class": "ve-pagination__next"
        }, [(_f = (_e = slots.next) == null ? void 0 : _e.call(slots, controls.value.next)) != null ? _f : createVNode(Button, controls.value.next, null)]), props.showFirstLastPage && createVNode("li", {
          "class": "ve-pagination__last"
        }, [(_h = (_g = slots.last) == null ? void 0 : _g.call(slots, controls.value.last)) != null ? _h : createVNode(Button, controls.value.last, null)]), props.showPerPageSelect && createVNode("li", {
          "class": "ve-pagination__per-page"
        }, [createVNode(Select, {
          "hide-details": true,
          "width": "95",
          "modelValue": perPage.value,
          "onUpdate:modelValue": ($event) => perPage.value = $event,
          "items": props.perPageOptions.map((v) => ({
            text: `${v} / \u9875`,
            value: parseInt(v, 10)
          }))
        }, null)]), props.showQuickJumper && createVNode("li", {
          "class": "ve-pagination__quick-jumper"
        }, [createVNode(Input, {
          "hide-details": true,
          "width": "60",
          "modelValue": internalPage.value,
          "onUpdate:modelValue": ($event) => internalPage.value = $event,
          "type": "number",
          "onKeydown": ({
            key
          }) => {
            if (key === keyValues.enter && internalPage.value && internalPage.value > 0 && internalPage.value <= lastPage.value) {
              page.value = internalPage.value;
              internalPage.value = void 0;
            }
          },
          "onBlur": () => {
            if (internalPage.value && internalPage.value > 0 && internalPage.value <= lastPage.value) {
              page.value = internalPage.value;
              internalPage.value = void 0;
            }
          }
        }, {
          prepend: () => createVNode("span", null, [createTextVNode("\u8DF3\u81F3")])
        })])])];
      }
    });
  }
});
export { Pagination };
//# sourceMappingURL=pagination.mjs.map
