var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
import { computed, toRef, createVNode, mergeProps } from "vue";
import "./styles/tabs.scss";
import { defineComponent } from "../../utils/define-component.mjs";
import { createSymbol } from "../../utils/symbol.mjs";
import { SlideGroup } from "../slide-group/slide-group.mjs";
import "../slide-group/slide-group-item.mjs";
import { makeDensityProps, useDensity } from "../../composables/density/index.mjs";
import { makeTagProps } from "../../composables/tag/index.mjs";
import { provideDefaults } from "../../composables/defaults/index.mjs";
import { Tab } from "./tab.mjs";
function parseItems(items) {
  if (!items)
    return [];
  return items.map((item) => {
    if (typeof item === "string")
      return {
        title: item,
        value: item
      };
    return item;
  });
}
const TabsKey = createSymbol("tabs");
const Tabs = defineComponent({
  name: "VeTabs",
  props: __spreadValues(__spreadValues({
    alignWithTitle: Boolean,
    color: String,
    direction: {
      type: String,
      default: "horizontal"
    },
    fixedTabs: Boolean,
    items: {
      type: Array,
      default: () => []
    },
    stacked: Boolean,
    backgroundColor: String,
    centered: Boolean,
    grow: Boolean,
    height: {
      type: [Number, String],
      default: void 0
    },
    hideSlider: Boolean,
    optional: Boolean,
    right: Boolean,
    sliderColor: String
  }, makeDensityProps()), makeTagProps()),
  setup(props, {
    slots,
    attrs
  }) {
    const parsedItems = computed(() => parseItems(props.items));
    const {
      densityClasses
    } = useDensity(props);
    provideDefaults({
      Tab: {
        color: toRef(props, "color"),
        direction: toRef(props, "direction"),
        stacked: toRef(props, "stacked"),
        fixed: toRef(props, "fixedTabs"),
        sliderColor: toRef(props, "sliderColor"),
        hideSlider: toRef(props, "hideSlider")
      }
    });
    return () => createVNode(SlideGroup, mergeProps({
      "class": ["ve-tabs", `ve-tabs--${props.direction}`, {
        "ve-tabs--align-with-title": props.alignWithTitle,
        "ve-tabs--centered": props.centered,
        "ve-tabs--fixed-tabs": props.fixedTabs,
        "ve-tabs--grow": props.grow,
        "ve-tabs--right": props.right,
        "ve-tabs--stacked": props.stacked
      }, densityClasses.value],
      "role": "tablist",
      "symbol": TabsKey,
      "mandatory": "force",
      "direction": props.direction
    }, attrs), {
      default: () => [slots.default ? slots.default() : parsedItems.value.map((item) => createVNode(Tab, mergeProps(item, {
        "key": item.title
      }), null))]
    });
  }
});
export { Tabs, TabsKey };
//# sourceMappingURL=tabs.mjs.map
