import { computed, unref } from "vue";
import { propsFactory, getCurrentInstanceName } from "../../utils/dist/index.mjs";
const DENSITIES = ["ultra-low", "low", "medium", "high", "ultra-high"];
const makeDensityProps = propsFactory({
  density: {
    type: String,
    default: "medium",
    validator: (v) => DENSITIES.includes(v)
  }
}, "density");
function useDensity(props, name = getCurrentInstanceName()) {
  const densityClasses = computed(() => {
    const { density } = unref(props);
    if (!name || !density || !DENSITIES.includes(density))
      return null;
    return `${name}--density-${density}`;
  });
  return {
    densityClasses
  };
}
export { DENSITIES, makeDensityProps, useDensity };
//# sourceMappingURL=index.mjs.map
