import { computed, unref } from "vue";
import { propsFactory } from "../../utils/dist/index.mjs";
const makeElevationProps = propsFactory({
  elevation: {
    type: [Number, String],
    validator(v) {
      const value = parseInt(v);
      return !isNaN(value) && value >= 0 && value <= 24;
    }
  }
}, "elevation");
function useElevation(props) {
  const elevationClasses = computed(() => {
    const { elevation } = unref(props);
    const classes = [];
    if (elevation == null)
      return classes;
    classes.push(`elevation-${elevation}`);
    return classes;
  });
  return { elevationClasses };
}
export { makeElevationProps, useElevation };
//# sourceMappingURL=index.mjs.map
