var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { computed, inject, reactive, ref, provide } from "vue";
import { propsFactory, getCurrentInstanceName, getCurrentInstance, convertToUnit } from "../../utils/dist/index.mjs";
import { findChildrenWithProvide } from "../../utils/helpers.mjs";
import { useResizeObserver } from "../resize-observer/index.mjs";
const LayoutKey = Symbol.for("veno-ui:layout");
const ROOT_ZINDEX = 1e3;
const makeLayoutProps = propsFactory({
  overlaps: {
    type: Array,
    default: () => []
  },
  fullHeight: Boolean
}, "layout");
function provideLayout(props, name = getCurrentInstanceName()) {
  const rootVm = getCurrentInstance("provideLayout");
  const parentLayout = inject(LayoutKey, null);
  const rootZIndex = computed(() => parentLayout ? parentLayout.rootZIndex.value - 100 : ROOT_ZINDEX);
  const itemIds = reactive([]);
  const itemMap = /* @__PURE__ */ new Map();
  const { resizeRef, contentRect: layoutRect } = useResizeObserver();
  const overlays = ref([]);
  function generate() {
    return itemIds.map((id) => {
      var _a, _b, _c, _d;
      const item = itemMap.get(id).value;
      return {
        id,
        size: Number(item.size),
        position: (_a = item.position) != null ? _a : "absolute",
        anchor: (_b = item.anchor) != null ? _b : "left",
        active: !!item.active,
        priority: Number((_c = item.priority) != null ? _c : 0),
        layoutSize: Number((_d = item.layoutSize) != null ? _d : item.size),
        disableTransition: Boolean(item.disableTransition)
      };
    }).sort((a, b) => b.priority - a.priority).reduce(({ items: items2, layer }, item) => ({
      items: [...items2, __spreadValues(__spreadValues({}, layer), item)],
      layer: __spreadProps(__spreadValues({}, layer), {
        [item.anchor]: layer[item.anchor] + (item.active ? item.layoutSize : 0)
      })
    }), {
      items: [],
      layer: { top: 0, right: 0, bottom: 0, left: 0 }
    });
  }
  const items = computed(() => generate().items);
  const getLayoutItem = (id) => items.value.find((item) => item.id === id);
  const computedOverlaps = computed(() => {
    var _a;
    const overlaps = (_a = props.overlaps) != null ? _a : [];
    const map = /* @__PURE__ */ new Map();
    for (const overlap of overlaps.filter((item) => item.includes(":"))) {
      const [top, bottom] = overlap.split(":");
      const topLayoutItem = getLayoutItem(top);
      const bottomLayoutItem = getLayoutItem(bottom);
      if (!topLayoutItem || !bottomLayoutItem)
        continue;
      const { anchor: topAlign, layoutSize: topAmount } = topLayoutItem;
      const { anchor: bottomAlign, layoutSize: bottomAmount } = bottomLayoutItem;
      if (!topAlign || !bottomAlign || !topAmount || !bottomAmount)
        continue;
      map.set(bottom, { anchor: topAlign, amount: topAmount });
      map.set(top, { anchor: bottomAlign, amount: -bottomAmount });
    }
    return map;
  });
  const transitionEnabled = computed(() => !items.value.some((ref2) => ref2.disableTransition));
  provide(LayoutKey, {
    register: (vm, id, itemProps) => {
      itemMap.set(id, itemProps);
      const instances = findChildrenWithProvide(LayoutKey, rootVm == null ? void 0 : rootVm.vnode);
      const instanceIndex = instances.indexOf(vm);
      if (instanceIndex > -1) {
        itemIds.splice(instanceIndex, 0, id);
      } else {
        itemIds.push(id);
      }
      const layoutItemStyles = computed(() => {
        const { items: items2 } = generate();
        const index = items2.findIndex((i) => i.id === id);
        const item = items2[index];
        if (!item)
          throw new Error(`Could not find layout item "${id}`);
        const overlap = computedOverlaps.value.get(id);
        if (overlap)
          item[overlap.anchor] += overlap.amount;
        const isHorizontal = item.anchor === "left" || item.anchor === "right";
        const isOppositeHorizontal = item.anchor === "right";
        const isOppositeVertical = item.anchor === "bottom";
        return __spreadValues({
          [item.anchor]: item.anchor === "right" ? "calc(0px + var(--ve-scrollbar-offset, 0px))" : "0px",
          height: isHorizontal ? `calc(100% - ${item.top}px - ${item.bottom}px)` : `${item.size}px`,
          marginLeft: isOppositeHorizontal ? void 0 : `${item.left}px`,
          marginRight: isOppositeHorizontal ? `${item.right}px` : void 0,
          marginTop: item.anchor !== "bottom" ? `${item.top}px` : void 0,
          marginBottom: item.anchor !== "top" ? `${item.bottom}px` : void 0,
          width: !isHorizontal ? `calc(100% - ${item.left}px - ${item.right}px)` : `${item.size}px`,
          zIndex: rootZIndex.value + items2.length * 2 - index * 2,
          transform: `translate${isHorizontal ? "X" : "Y"}(${(item.active ? 0 : -110) * (isOppositeHorizontal || isOppositeVertical ? -1 : 1)}%)`,
          position: item.position === "absolute" || rootZIndex.value !== ROOT_ZINDEX ? "absolute" : "fixed"
        }, transitionEnabled.value ? void 0 : { transition: "none" });
      });
      const layoutItemScrimStyles = computed(() => ({
        zIndex: layoutItemStyles.value.zIndex - 1,
        position: rootZIndex.value === ROOT_ZINDEX ? "fixed" : "absolute"
      }));
      return {
        layoutItemStyles,
        layoutItemScrimStyles
      };
    },
    unregister: (id) => {
      itemIds.splice(itemIds.indexOf(id), 1);
      itemMap.delete(id);
    },
    mainStyles: computed(() => {
      const { layer } = generate();
      return __spreadValues({
        position: "relative",
        paddingLeft: convertToUnit(layer.left),
        paddingRight: convertToUnit(layer.right),
        paddingTop: convertToUnit(layer.top),
        paddingBottom: convertToUnit(layer.bottom)
      }, transitionEnabled.value ? void 0 : { transition: "none" });
    }),
    getLayoutItem,
    items,
    layoutRect,
    rootZIndex,
    overlays
  });
  return {
    layoutClasses: computed(() => ({
      [`${name}--full-height`]: props.fullHeight
    })),
    layoutStyles: computed(() => ({
      zIndex: rootZIndex.value
    })),
    getLayoutItem,
    items,
    layoutRect,
    layoutRef: resizeRef
  };
}
function useLayout() {
  const layout = inject(LayoutKey);
  if (!layout)
    throw new Error("[VenoUi] Could not find layout instance");
  return layout;
}
export { LayoutKey, ROOT_ZINDEX, makeLayoutProps, provideLayout, useLayout };
//# sourceMappingURL=layout.mjs.map
