var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { ref, computed, onMounted, onBeforeUnmount, provide, inject } from "vue";
import { propsFactory, throttle } from "../../utils/dist/index.mjs";
import { useRouterHistory, useRoute } from "../router/index.mjs";
const NamedAnchorKey = Symbol.for("veno-ui:named-anchor");
const makeNamedAnchor = propsFactory({
  offset: {
    type: [String, Number],
    default: 12
  },
  scrollTarget: {
    type: [String, Object]
  }
}, "named-anchor");
function useNamedAnchor(props) {
  const active = ref();
  const names = ref(/* @__PURE__ */ new Set());
  const offset = computed(() => parseInt(props.offset, 10));
  const scrollTarget = computed(() => typeof props.scrollTarget === "string" ? document.querySelector(props.scrollTarget) : props.scrollTarget);
  const scrolling = ref(false);
  const { isWebHashHistory } = useRouterHistory();
  const route = useRoute();
  let timeout = 0;
  const activate = (name) => {
    var _a, _b, _c;
    const target = document.getElementById(name);
    if (target) {
      clearTimeout(timeout);
      scrolling.value = true;
      timeout = setTimeout(() => scrolling.value = false, 800);
      const container = (_a = scrollTarget.value) != null ? _a : window;
      const offsetTop = (_c = (_b = scrollTarget.value) == null ? void 0 : _b.scrollTop) != null ? _c : window.scrollY;
      container.scrollTo({
        top: target.getBoundingClientRect().top + offsetTop - offset.value,
        behavior: "smooth"
      });
    }
    active.value = name;
  };
  const findActiveHash = () => {
    var _a, _b;
    if (scrolling.value || !names.value.size)
      return;
    const offsetTop = ((_a = scrollTarget.value) == null ? void 0 : _a.getBoundingClientRect().top) || 0;
    active.value = (_b = [...names.value].reduce((pos, name) => {
      const el = document.getElementById(name);
      if (el && document.documentElement.contains(el)) {
        const box = el.getBoundingClientRect();
        pos.push({
          name,
          top: box.top - offsetTop,
          height: box.height
        });
      }
      return pos;
    }, []).sort((a, b) => a.top - b.top).reduce((prev, item) => {
      if (item.top + item.height < 0) {
        return prev;
      }
      if (item.top <= props.offset) {
        if (prev === null) {
          return item;
        } else if (item.top === prev.top) {
          if (item.name === active.value) {
            return item;
          } else {
            return prev;
          }
        } else if (item.top > prev.top) {
          return item;
        } else {
          return prev;
        }
      }
      return prev;
    }, null)) == null ? void 0 : _b.name;
  };
  const onScroll = throttle(findActiveHash, 17);
  onMounted(() => {
    var _a, _b;
    document.addEventListener("scroll", onScroll, true);
    if (isWebHashHistory.value && ((_b = (_a = route.value) == null ? void 0 : _a.query) == null ? void 0 : _b.anchor)) {
      activate(route.value.query.anchor);
    } else if (window.location.hash) {
      activate(decodeURIComponent(window.location.hash.substring(1)));
    } else {
      findActiveHash();
    }
  });
  onBeforeUnmount(() => {
    document.removeEventListener("scroll", onScroll, true);
  });
  const namedAnchor = {
    names,
    active,
    activate,
    register: (name) => {
      names.value.add(name);
    },
    unregister: (name) => {
      names.value.delete(name);
      if (active.value === name) {
        active.value = void 0;
      }
    }
  };
  provide(NamedAnchorKey, namedAnchor);
  return namedAnchor;
}
const makeNamedAnchorItem = propsFactory({
  value: {
    type: String,
    required: true
  }
}, "named-anchor-item");
function useNamedAnchorItem(props) {
  const parent = inject(NamedAnchorKey);
  if (!parent)
    throw new Error("[VenoUi] Could not find namedAnchor instance");
  const { isWebHashHistory } = useRouterHistory();
  const item = __spreadProps(__spreadValues({}, parent), {
    isWebHashHistory,
    to: computed(() => isWebHashHistory.value ? { query: { anchor: props.value }, replace: true } : { hash: `#${props.value}`, replace: true }),
    isActive: computed(() => parent.active.value === props.value)
  });
  parent.register(props.value);
  onBeforeUnmount(() => {
    parent.unregister(props.value);
  });
  return item;
}
export { NamedAnchorKey, makeNamedAnchor, makeNamedAnchorItem, useNamedAnchor, useNamedAnchorItem };
//# sourceMappingURL=index.mjs.map
