var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { ref, computed, onBeforeUnmount, provide, inject } from "vue";
import { propsFactory, getUid } from "../../utils/dist/index.mjs";
import { useProxiedModel } from "../proxied-model/index.mjs";
import { singleOpenStrategy } from "./open-strategies/singleOpenStrategy.mjs";
import { multipleOpenStrategy } from "./open-strategies/multipleOpenStrategy.mjs";
import { classicSelectStrategy } from "./select-strategies/classicSelectStrategy.mjs";
import { independentSelectStrategy } from "./select-strategies/independentSelectStrategy.mjs";
import { leafSelectStrategy } from "./select-strategies/leafSelectStrategy.mjs";
import { classicActiveStrategy } from "./active-strategies/classicActiveStrategy.mjs";
const NestedKey = Symbol.for("veno-ui:nested");
const emptyNested = {
  id: ref(null),
  root: {
    register: () => null,
    unregister: () => null,
    parents: ref(/* @__PURE__ */ new Map()),
    children: ref(/* @__PURE__ */ new Map()),
    open: () => null,
    select: () => null,
    opened: ref(/* @__PURE__ */ new Set()),
    selected: ref(/* @__PURE__ */ new Map()),
    active: ref(/* @__PURE__ */ new Set()),
    activate: () => null,
    selectedValues: ref([])
  }
};
const makeNestedProps = propsFactory({
  selectStrategy: [String, Function],
  openStrategy: [String, Function],
  activeStrategy: [String, Function],
  opened: {
    type: [Boolean, Array],
    default: () => []
  },
  selected: Array,
  active: Array,
  deleteAfterUnmount: {
    type: Boolean,
    default: true
  }
}, "nested");
const useNested = (props) => {
  let isUnmounted = false;
  const children = ref(/* @__PURE__ */ new Map());
  const parents = ref(/* @__PURE__ */ new Map());
  const opened = useProxiedModel(props, "opened", props.opened, (v) => typeof v === "boolean" ? new Set(v === true ? [...children.value.keys()] : []) : new Set(v), (v) => [...v.values()]);
  const active = useProxiedModel(props, "active", props.active, (v) => new Set(v), (v) => [...v.values()]);
  const activeStrategy = computed(() => {
    if (typeof props.activeStrategy === "string") {
      switch (props.activeStrategy) {
        case "single":
          return classicActiveStrategy(true);
        case "multiple":
        default:
          return classicActiveStrategy();
      }
    }
    return props.activeStrategy;
  });
  const selectStrategy = computed(() => {
    if (typeof props.selectStrategy === "string") {
      switch (props.selectStrategy) {
        case "single-leaf":
          return leafSelectStrategy(true);
        case "leaf":
          return leafSelectStrategy();
        case "independent":
          return independentSelectStrategy;
        case "classic":
        default:
          return classicSelectStrategy;
      }
    }
    return props.selectStrategy;
  });
  const openStrategy = computed(() => {
    if (typeof props.openStrategy === "string") {
      switch (props.openStrategy) {
        case "single":
          return singleOpenStrategy;
        case "multiple":
        default:
          return multipleOpenStrategy;
      }
    }
    return props.openStrategy;
  });
  const selected = useProxiedModel(props, "selected", props.selected, (v) => selectStrategy.value.in(v, children.value, parents.value), (v) => selectStrategy.value.out(v, children.value, parents.value));
  onBeforeUnmount(() => {
    isUnmounted = true;
  });
  const nested = {
    id: ref(null),
    root: {
      opened,
      selected,
      active,
      selectedValues: computed(() => {
        const arr = [];
        for (const [key, value] of selected.value.entries()) {
          if (value === "on")
            arr.push(key);
        }
        return arr;
      }),
      register: (id, parentId, isGroup) => {
        parentId && parents.value.set(id, parentId);
        isGroup && children.value.set(id, []);
        if (parentId != null) {
          children.value.set(parentId, [...children.value.get(parentId) || [], id]);
        }
      },
      unregister: (id) => {
        var _a;
        if (isUnmounted)
          return;
        children.value.delete(id);
        const parent = parents.value.get(id);
        if (parent) {
          const list = (_a = children.value.get(parent)) != null ? _a : [];
          children.value.set(parent, list.filter((child) => child !== id));
        }
        parents.value.delete(id);
        opened.value.delete(id);
        if (props.deleteAfterUnmount) {
          active.value.delete(id);
          selected.value.delete(id);
        }
      },
      open: (id, value, event) => {
        const newOpened = openStrategy.value({
          id,
          value,
          opened: new Set(opened.value),
          children: children.value,
          parents: parents.value,
          event
        });
        newOpened && (opened.value = newOpened);
      },
      select: (id, value, event) => {
        const newSelected = selectStrategy.value.select({
          id,
          value,
          selected: new Map(selected.value),
          children: children.value,
          parents: parents.value,
          event
        });
        newSelected && (selected.value = newSelected);
      },
      activate: (id, value, event) => {
        const newActive = activeStrategy.value({
          id,
          value,
          active: new Set(active.value),
          children: children.value,
          parents: parents.value,
          event
        });
        newActive && (active.value = newActive);
      },
      children,
      parents
    }
  };
  provide(NestedKey, nested);
  return nested.root;
};
const useNestedItem = (id) => {
  const parent = inject(NestedKey, emptyNested);
  const computedId = computed(() => {
    var _a;
    return (_a = id.value) != null ? _a : getUid().toString();
  });
  const item = __spreadProps(__spreadValues({}, parent), {
    id: computedId,
    parent: computed(() => parent.root.parents.value.get(computedId.value)),
    select: (selected, e) => parent.root.select(computedId.value, selected, e),
    isSelected: computed(() => parent.root.selected.value.get(computedId.value) === "on"),
    activate: (activated, e) => parent.root.activate(computedId.value, activated, e),
    isActive: computed(() => parent.root.active.value.has(computedId.value))
  });
  parent.root.register(computedId.value, parent.id.value, false);
  onBeforeUnmount(() => {
    parent.root.unregister(computedId.value);
  });
  return item;
};
const useNestedGroup = (props) => {
  const parent = inject(NestedKey, emptyNested);
  const id = computed(() => {
    var _a;
    return (_a = props.value) != null ? _a : getUid().toString();
  });
  const group = __spreadProps(__spreadValues({}, parent), {
    id,
    open: (open, e) => parent.root.open(id.value, open, e),
    isOpen: computed(() => parent.root.opened.value.has(id.value)),
    isSelected: computed(() => parent.root.selected.value.get(id.value) === "on"),
    isIndeterminate: computed(() => parent.root.selected.value.get(id.value) === "indeterminate")
  });
  parent.root.register(id.value, parent.id.value, true);
  onBeforeUnmount(() => {
    parent.root.unregister(id.value);
  });
  provide(NestedKey, group);
  return group;
};
export { makeNestedProps, useNested, useNestedGroup, useNestedItem };
//# sourceMappingURL=index.mjs.map
