var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
import { inject, computed, unref, provide, ref, watchEffect, watch } from "vue";
import { propsFactory, getCurrentInstance, colorToOnColorHex, colorToRGB, getLuma, IN_BROWSER, deepMerge } from "../../utils/dist/index.mjs";
import defaultOptions from "./default-options.mjs";
const ThemeKey = Symbol.for("veno-ui:theme");
const makeThemeProps = propsFactory({
  theme: String
}, "theme");
const parseThemeOptions = (options = defaultOptions) => {
  if (!options) {
    return __spreadProps(__spreadValues({}, defaultOptions), { isDisabled: true });
  }
  return deepMerge(defaultOptions, options);
};
function createCssClass(selector, content) {
  return [
    `${selector} {
`,
    ...content.map((line) => `  ${line};
`),
    "}\n"
  ];
}
function createTheme(app, options) {
  const head = app._context.provides.usehead;
  const parsedOptions = parseThemeOptions(options);
  const styleEl = ref();
  const current = ref(parsedOptions.defaultTheme);
  const themes = ref(parsedOptions.themes);
  const computedThemes = computed(() => {
    return Object.keys(themes.value).reduce((obj, key) => {
      const theme = themes.value[key];
      for (const color of Object.keys(theme.colors)) {
        if (/on-[a-z]/.test(color) || theme.colors[`on-${color}`])
          continue;
        theme.colors[`on-${color}`] = colorToOnColorHex(theme.colors[color]);
      }
      obj[key] = theme;
      return obj;
    }, {});
  });
  const styles = computed(() => {
    const lines = [];
    for (const themeName of Object.keys(computedThemes.value)) {
      const theme = computedThemes.value[themeName];
      lines.push(...createCssClass(`.ve-theme--${themeName}`, [
        ...genCssVariables(themeName),
        ...Object.keys(theme.variables).map((key) => {
          const value = theme.variables[key];
          const color = typeof value === "string" && value.startsWith("#") ? colorToRGB(value) : void 0;
          const rgb = color ? `${color.r}, ${color.g}, ${color.b}` : void 0;
          return `--ve-${key}: ${rgb != null ? rgb : value}`;
        })
      ]));
      if (theme.dark) {
        for (const key of Object.keys(theme.colors)) {
          if (/on-[a-z]/.test(key)) {
            lines.push(...createCssClass(`.${key}`, [
              `color: rgb(var(--ve-theme-${key})) !important`
            ]));
          } else {
            lines.push(...createCssClass(`.bg-${key}`, [
              `--ve-theme-overlay-multiplier: var(--ve-theme-${key}-overlay-multiplier)`,
              `background: rgb(var(--ve-theme-${key})) !important`,
              `color: rgb(var(--ve-theme-on-${key})) !important`
            ]), ...createCssClass(`.text-${key}`, [
              `color: rgb(var(--ve-theme-${key})) !important`
            ]), ...createCssClass(`.border-${key}`, [
              `--ve-border-color: var(--ve-theme-${key})`
            ]));
          }
        }
      }
    }
    return lines.map((str, i) => i === 0 ? str : `    ${str}`).join("");
  });
  function genCssVariables(name) {
    const theme = computedThemes.value[name];
    if (!theme)
      throw new Error(`Could not find theme ${name}`);
    const lightOverlay = theme.dark ? 2 : 1;
    const darkOverlay = theme.dark ? 1 : 2;
    const variables = [];
    for (const [key, value] of Object.entries(theme.colors)) {
      const rgb = colorToRGB(value);
      variables.push(`--ve-theme-${key}: ${rgb.r},${rgb.g},${rgb.b}`);
      if (!key.startsWith("on-")) {
        variables.push(`--ve-theme-${key}-overlay-multiplier: ${getLuma(value) > 0.18 ? lightOverlay : darkOverlay}`);
      }
    }
    return variables;
  }
  if (head) {
    head.addHeadObjs(computed(() => ({
      style: [{
        children: styles.value,
        type: "text/css",
        id: "veno-ui-theme-stylesheet"
      }]
    })));
    if (IN_BROWSER) {
      watchEffect(() => head.updateDOM());
    }
  } else {
    let updateStyles = function() {
      if (parsedOptions.isDisabled)
        return;
      genStyleElement();
      if (styleEl.value)
        styleEl.value.innerHTML = styles.value;
    }, genStyleElement = function() {
      if (typeof document === "undefined" || styleEl.value)
        return;
      const el = document.createElement("style");
      el.type = "text/css";
      el.id = "veno-ui-theme-stylesheet";
      styleEl.value = el;
      document.head.appendChild(styleEl.value);
    };
    watch(themes, updateStyles, { deep: true, immediate: true });
  }
  return {
    isDisabled: parsedOptions.isDisabled,
    themes: computedThemes,
    setTheme: (key, theme) => themes.value[key] = theme,
    getTheme: (key) => computedThemes.value[key],
    current,
    themeClasses: computed(() => {
      return parsedOptions.isDisabled ? void 0 : `ve-theme--${current.value}`;
    })
  };
}
function provideTheme(props) {
  getCurrentInstance("provideTheme");
  const theme = inject(ThemeKey, null);
  if (!theme)
    throw new Error("Could not find theme injection");
  const current = computed(() => {
    const { theme: propTheme } = unref(props);
    if (propTheme && propTheme.includes(":")) {
      const [theme1, theme2] = propTheme.split(":");
      return (theme == null ? void 0 : theme.current.value) === theme1 ? theme2 : theme1;
    }
    return propTheme != null ? propTheme : theme == null ? void 0 : theme.current.value;
  });
  const themeClasses = computed(() => {
    return theme.isDisabled ? void 0 : `ve-theme--${current.value}`;
  });
  const newTheme = __spreadProps(__spreadValues({}, theme), {
    current,
    themeClasses
  });
  provide(ThemeKey, newTheme);
  return newTheme;
}
function useTheme() {
  getCurrentInstance("useTheme");
  const provider = inject(ThemeKey, null);
  if (!provider)
    throw new Error("Could not find theme injection");
  return provider;
}
export { ThemeKey, createTheme, makeThemeProps, provideTheme, useTheme };
//# sourceMappingURL=index.mjs.map
